java.lang.Object
io.jooby.Jooby
io.jooby.quartz.QuartzApp
REST API over
Scheduler operations.- Since:
- 2.5.1
- Author:
- edgar
-
Nested Class Summary
Nested classes/interfaces inherited from interface io.jooby.Router
Router.Match -
Field Summary
-
Constructor Summary
Constructors -
Method Summary
Methods inherited from class io.jooby.Jooby
after, attribute, attribute, before, converter, createApp, decoder, dispatch, dispatch, domain, domain, encoder, encoder, error, errorCode, errorCode, executor, getAttributes, getBasePackage, getBeanConverters, getBufferFactory, getClassLoader, getConfig, getContextPath, getConverters, getEnvironment, getErrorHandler, getExecutionMode, getFlashCookie, getLocales, getLog, getName, getRouter, getRouterOptions, getRoutes, getServerOptions, getServices, getSessionStore, getStartupSummary, getTmpdir, getVersion, getWorker, install, install, install, install, install, install, isStarted, isStopped, isTrustProxy, match, match, mount, mount, mount, mount, mvc, mvc, mvc, mvc, onStarted, onStarting, onStop, path, ready, registry, require, require, require, route, routes, runApp, runApp, runApp, runApp, setBasePackage, setBufferFactory, setContextAsService, setContextPath, setCurrentUser, setDefaultWorker, setEnvironment, setEnvironmentOptions, setExecutionMode, setFlashCookie, setHiddenMethod, setHiddenMethod, setLateInit, setLocales, setLocales, setName, setRouterOptions, setServerOptions, setSessionStore, setStartupSummary, setTmpdir, setTrustProxy, setVersion, setWorker, sse, start, start, stop, toString, use, ws
-
Constructor Details
-
QuartzApp
public QuartzApp(@Nullable org.quartz.Scheduler scheduler) New quartz app.- Parameters:
scheduler- Scheduler to use.
-
QuartzApp
public QuartzApp()New quartz app.
-